@@ -1,9 +1,12 @@
+import logging
 from abc import ABC
 from typing import Union, List
 
 import numpy as np
 import pandas as pd
 
+logger = logging.getLogger(__name__)
+
 
 class TimeSeries(ABC):
     def __init__(self, time: Union[list, np.ndarray] = None):
@@ -143,7 +146,14 @@ class GPSSeries(TimeSeries):
 
         :return: Returns the lat/lon coordinates as list of list for easy visualization using ipyleaflet
         """
-        return [[lat, lon] for lat, lon in zip(self.lat, self.lon)]
+        if not np.array_equal(self.lat, np.array(None)) and not np.array_equal(self.lat, np.array(None)):
+            return [[lat, lon] for lat, lon in zip(self.lat, self.lon)]
+        elif len(self.lat) == 0 and len(self.lon) == 0:
+            logger.warning("Coordinates are empty")
+            return [[]]
+        else:
+            logger.warning("Coordinates are empty")
+            return [[]]
 
 
 class PressureSeries(TimeSeries):
